"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.delegation53 = void 0;
var aws_iam_1 = __importDefault(require("@aws-cdk/aws-iam"));
function delegation53(eksr, props) {
    var toolsNS = props.delegationDnsNamespace || 'kuber';
    var ns = eksr.eks.addManifest("NS-" + eksr.props.baseName + "-" + toolsNS + "-delegation53", {
        apiVersion: 'v1',
        kind: 'Namespace',
        metadata: { name: toolsNS },
    });
    var delegation53SA = eksr.eks.addServiceAccount("SA-" + eksr.props.baseName + "-" + toolsNS + "-delegation53", {
        name: toolsNS + "-delegation53",
        namespace: toolsNS,
    });
    delegation53SA.node.addDependency(ns);
    delegation53SA.addToPolicy(new aws_iam_1.default.PolicyStatement({
        effect: aws_iam_1.default.Effect.ALLOW,
        actions: ['route53:ChangeResourceRecordSets'],
        resources: ['arn:aws:route53:::hostedzone/*'],
    }));
    delegation53SA.addToPolicy(new aws_iam_1.default.PolicyStatement({
        effect: aws_iam_1.default.Effect.ALLOW,
        actions: ['route53:ListHostedZones', 'route53:ListResourceRecordSets'],
        resources: ['*'],
    }));
    eksr.eks.addManifest("Deployment-" + eksr.props.baseName + "-" + toolsNS + "-delegation53", {
        apiVersion: 'apps/v1',
        kind: 'Deployment',
        metadata: {
            name: toolsNS + "-delegation53",
            namespace: delegation53SA.serviceAccountNamespace,
        },
        spec: {
            strategy: { type: 'Recreate' },
            selector: {
                matchLabels: {
                    app: toolsNS + "-delegation53",
                },
            },
            template: {
                metadata: {
                    labels: {
                        app: toolsNS + "-delegation53",
                    },
                },
                spec: {
                    serviceAccount: delegation53SA.serviceAccountName,
                    containers: [
                        {
                            name: "aws-cli",
                            image: 'fastandfearless/dev-base-container:latest',
                            args: ['/bin/sleep', '100000'],
                        },
                        {
                            name: "aws-delegation53",
                            image: props.delegation53Image || 'fastandfearless/aws-delegation53',
                            env: [
                                {
                                    name: 'ZONES',
                                    value: props.zones.map(function (i) { return i.zoneName; }).join(','),
                                },
                                {
                                    name: 'TOPROLEARN',
                                    value: props.rolesARN.join(","),
                                },
                            ],
                            args: ['/bin/sleep', '100000'],
                        },
                    ],
                    securityContext: {
                        fsGroup: 65534,
                    },
                },
            },
        },
    }).node.addDependency(delegation53SA);
}
exports.delegation53 = delegation53;
//# sourceMappingURL=delegation53.js.map