"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.externalDNS = void 0;
var iam = require("@aws-cdk/aws-iam");
var aws_iam_1 = require("@aws-cdk/aws-iam");
function externalDNS(eksr, props) {
    var toolsNS = props.externalDnsNamespace || 'kuber';
    var ns = eksr.eks.addManifest("NS-" + eksr.props.baseName + "-" + toolsNS + "-externaldns", {
        apiVersion: 'v1',
        kind: 'Namespace',
        metadata: { name: toolsNS },
    });
    var dnsAdmin = eksr.eks.addServiceAccount("SA-" + eksr.props.baseName + "-" + toolsNS + "-externaldns", {
        name: toolsNS + "-externaldns",
        namespace: toolsNS,
    });
    dnsAdmin.node.addDependency(ns);
    dnsAdmin.addToPolicy(new aws_iam_1.PolicyStatement({
        effect: iam.Effect.ALLOW,
        actions: ['route53:ChangeResourceRecordSets'],
        resources: ['arn:aws:route53:::hostedzone/*'],
    }));
    dnsAdmin.addToPolicy(new aws_iam_1.PolicyStatement({
        effect: iam.Effect.ALLOW,
        actions: ['route53:ListHostedZones', 'route53:ListResourceRecordSets'],
        resources: ['*'],
    }));
    eksr.eks
        .addManifest("CBR-" + eksr.props.baseName + "-" + toolsNS + "-viewer", {
        apiVersion: 'rbac.authorization.k8s.io/v1beta1',
        kind: 'ClusterRoleBinding',
        metadata: {
            name: toolsNS + "-externaldns-viewer",
        },
        roleRef: {
            apiGroup: 'rbac.authorization.k8s.io',
            kind: 'ClusterRole',
            name: toolsNS + "-externaldns-viewer",
        },
        subjects: [
            {
                kind: 'ServiceAccount',
                name: dnsAdmin.serviceAccountName,
                namespace: dnsAdmin.serviceAccountNamespace,
            },
        ],
    })
        .node.addDependency(dnsAdmin);
    eksr.eks
        .addManifest("CR-" + eksr.props.baseName + "-" + toolsNS + "-viewer", {
        apiVersion: 'rbac.authorization.k8s.io/v1beta1',
        kind: 'ClusterRole',
        metadata: { name: toolsNS + "-externaldns-viewer" },
        rules: [
            {
                apiGroups: [''],
                resources: ['services', 'endpoints', 'pods'],
                verbs: ['get', 'watch', 'list'],
            },
            {
                apiGroups: ['extensions', 'networking.k8s.io'],
                resources: ['ingresses'],
                verbs: ['get', 'watch', 'list'],
            },
            {
                apiGroups: [''],
                resources: ['nodes'],
                verbs: ['list', 'watch'],
            },
        ],
    })
        .node.addDependency(dnsAdmin);
    var externalDnsImage = props.externalDnsImage || 'registry.opensource.zalan.do/teapot/external-dns:latest';
    eksr.eks
        .addManifest("Deployment-" + eksr.props.baseName + "-" + toolsNS + "-externaldns", {
        apiVersion: 'apps/v1',
        kind: 'Deployment',
        metadata: {
            name: toolsNS + "-externaldns",
            namespace: dnsAdmin.serviceAccountNamespace,
        },
        spec: {
            strategy: { type: 'Recreate' },
            selector: {
                matchLabels: {
                    app: toolsNS + "-externaldns",
                },
            },
            template: {
                metadata: {
                    labels: {
                        app: toolsNS + "-externaldns",
                    },
                },
                spec: {
                    serviceAccount: dnsAdmin.serviceAccountName,
                    containers: [
                        {
                            name: 'externaldns',
                            image: externalDnsImage,
                            args: __spreadArrays([
                                '--source=service',
                                '--source=ingress'
                            ], props.zones.map(function (zone) { return "--domain-filter=" + zone.zoneName; }), [
                                '--provider=aws',
                                '--policy=upsert-only',
                                '--aws-zone-type=public',
                                '--registry=txt',
                                "--txt-owner-id=" + toolsNS + "-externaldns",
                            ]),
                        },
                    ],
                    securityContext: {
                        fsGroup: 65534,
                    },
                },
            },
        },
    })
        .node.addDependency(dnsAdmin);
}
exports.externalDNS = externalDNS;
//# sourceMappingURL=external-dns.js.map